@@ -3,9 +3,6 @@ package Perlanet::Simple;
 use strict;
 use warnings;
 
-use 5.6.0;
-our $VERSION = '0.58';
-
 use Moose;
 use namespace::autoclean;
 
